@@ -3,7 +3,7 @@
 
 # sun_gtk is a part of sun.
 
-# Copyright 2015-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
+# Copyright 2015-2023 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
 # All rights reserved.
 
 # sun is a tray notification applet for informing about
@@ -22,49 +22,45 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+
 import gi
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from gi.repository.GdkPixbuf import Pixbuf
-import subprocess
-from sun.licenses import lic, abt
+
+from sun.licenses import ABOUT, LICENSE
 from sun.__metadata__ import (
     __all__,
     __email__,
     __author__,
     __version__,
     __website__,
-    bin_path,
-    icon_path
+    data_configs
 )
-from sun.cli.tool import check_updates, daemon_status
-from sun.utils import os_info
 
 
-class GtkStatusIcon:
+from sun.utils import Utilities
+from sun.configs import Configs
+from sun.cli.tool import Tools
+
+
+class GtkStatusIcon(Configs):
 
     def __init__(self):
-        self.sun_icon = f'{icon_path}{__all__}.png'
+        super(Configs, self).__init__()
+        self.data_configs: dict = data_configs
+        self.tool = Tools()
+        self.sun_icon: str = f'{self.data_configs["icon_path"]}{__all__}.png'
         self.status_icon = Gtk.StatusIcon()
         self.status_icon.set_from_file(self.sun_icon)
         self.status_icon.connect('popup-menu', self.right_click_event)
-        self.cmd = f'{bin_path}sun_daemon'
-        self.init_daemon()
-
-    def init_daemon(self):
-        '''Start daemon when gtk loaded'''
-        if daemon_status() == 'SUN not running':
-            subprocess.call(f'{self.cmd} &', shell=True)
-            return 'Daemon Starts'
-        else:
-            return 'Daemon is already running...'
 
     def right_click_event(self, icon, button, time):
-        '''Handler menu and submenu'''
+        """ Handler menu and submenu. """
 
         # Set Gtk menu and submenu
-        self.menu = Gtk.Menu()
         submenu = Gtk.Menu()
+        self.menu = Gtk.Menu()
 
         # Creating Start submenu handler
         img_start = Gtk.Image()
@@ -117,10 +113,10 @@ class GtkStatusIcon:
         # Creating Os Info menu handler
         img_info = Gtk.Image()
         img_info.set_from_stock(Gtk.STOCK_INFO, 1)
-        osInfo = Gtk.ImageMenuItem('Os Info')
-        osInfo.connect('activate', self.show_os_info)
-        osInfo.set_image(img_info)
-        self.menu.append(osInfo)
+        os_info = Gtk.ImageMenuItem('Os Info')
+        os_info.connect('activate', self.show_os_info)
+        os_info.set_image(img_info)
+        self.menu.append(os_info)
 
         # Creating seperator
         sep = Gtk.SeparatorMenuItem()
@@ -137,17 +133,17 @@ class GtkStatusIcon:
         # Creating Quit menu handler
         img_quit = Gtk.Image()
         img_quit.set_from_stock(Gtk.STOCK_QUIT, 1)
-        quit = Gtk.ImageMenuItem('Quit')
-        quit.connect('activate', Gtk.main_quit)
-        quit.set_image(img_quit)
-        self.menu.append(quit)
+        quit_and_exit = Gtk.ImageMenuItem('Quit')
+        quit_and_exit.connect('activate', Gtk.main_quit)
+        quit_and_exit.set_image(img_quit)
+        self.menu.append(quit_and_exit)
 
         self.menu.show_all()
 
         self.menu.popup(None, None, None, self.status_icon, button, time)
 
     def message(self, data, title):
-        '''Method to display messages to the user'''
+        """ Method to display messages to the user. """
         msg = Gtk.MessageDialog(type=Gtk.MessageType.INFO,
                                 buttons=Gtk.ButtonsType.CLOSE)
         msg.set_resizable(0)
@@ -158,12 +154,12 @@ class GtkStatusIcon:
         msg.destroy()
 
     def show_check_updates(self, widget):
-        '''Show message updates'''
-        title = 'SUN - Check Updates'
-        data, packages = check_updates()
-        count = len(packages)
+        """ Show message updates. """
+        title: str = 'SUN - Check Updates'
+        data, packages = self.tool.check_updates()
+        count: int = len(packages)
         if count > 0:
-            packages = packages[:10]
+            packages: list = packages[:10]
             if count > 10:
                 packages += ['\nand more...']
             self.message('{0}\n{1}'.format(data, '\n'.join(packages)), title)
@@ -171,13 +167,13 @@ class GtkStatusIcon:
             self.message(data, title)
 
     def show_os_info(self, widget):
-        '''Show message OS info'''
-        title = 'SUN - OS Info'
-        data = os_info()
+        """ Show message OS info. """
+        title: str = 'SUN - OS Info'
+        data: str = Utilities().os_info()
         self.message(data, title)
 
     def show_about_dialog(self, widget):
-        '''Show message About info'''
+        """ Show message About info. """
         about_dialog = Gtk.AboutDialog()
         about_dialog.set_destroy_with_parent(True)
         about_dialog.set_name('SUN - About')
@@ -185,36 +181,37 @@ class GtkStatusIcon:
         about_dialog.set_program_name('SUN')
         about_dialog.set_version(__version__)
         about_dialog.set_authors([f'{__author__} <{__email__}>'])
-        about_dialog.set_license('\n'.join(lic))
+        about_dialog.set_license('\n'.join(LICENSE))
         about_dialog.set_website(__website__)
         about_dialog.set_logo(Pixbuf.new_from_file(self.sun_icon))
-        about_dialog.set_comments(abt)
+        about_dialog.set_comments(ABOUT)
         about_dialog.run()
         about_dialog.destroy()
 
     def daemon_start(self, widget):
-        '''Show message and start the daemon'''
-        title = 'Daemon'
-        data = self.init_daemon()
+        """ Show message and start the daemon. """
+        title: str = 'SUN daemon'
+        data: str = 'SUN daemon starts...'
+        data: str = self.tool.daemon_process('start', data)
         self.message(data, title)
 
     def daemon_stop(self, widget):
-        '''Show message and stop the daemon'''
-        title = 'Daemon'
-        subprocess.call('killall sun_daemon', shell=True)
-        data = 'Daemon stops'
+        """ Show message and stop the daemon. """
+        title: str = 'SUN daemon'
+        data: str = 'SUN daemon stops'
+        data: str = self.tool.daemon_process('stop', data)
         self.message(data, title)
 
     def daemon_restart(self, widget):
-        '''Show message and restart the daemon'''
-        title = 'Daemon'
-        subprocess.call('killall sun_daemon', shell=True)
-        subprocess.call(f'{self.cmd} &', shell=True)
-        data = 'Daemon restarts'
+        """ Show message and restart the daemon. """
+        title: str = 'SUN daemon'
+        data: str = 'SUN daemon restarts...'
+        data: str = self.tool.daemon_process('restart', data)
         self.message(data, title)
 
     def show_daemon_status(self, widget):
-        '''Show message status about the daemon'''
-        title = 'Daemon'
-        data = daemon_status()
+        """ Show message status about the daemon. """
+        daemon: str = 'sun_daemon'
+        title: str = 'SUN daemon'
+        data: str = ('SUN is running...' if self.tool.process_status(process_name=daemon) else 'SUN is not running')
         self.message(data, title)
