@@ -1,16 +1,16 @@
 import subprocess
-from sun.cli.tool import check_updates, daemon_status
+from sun.cli.tool import check_updates, process_status
 
 
 def test_check_updates():
     message, packages = check_updates()
     if len(packages) == 0:
-        assert message == 'No news is good news !'
+        assert message == 'No news is good news!'
 
 
 def test_daemon_status():
     out = subprocess.getoutput('ps -a')
     if 'sun_daemon' in out:
-        assert 'SUN is running...' == daemon_status()
+        assert 'SUN is running...' == process_status()
     else:
-        assert 'SUN not running' == daemon_status()
\ No newline at end of file
+        assert 'SUN not running' == process_status()
